@@ -17,11 +17,11 @@ Module::Starter::Simple - a simple, comprehensive Module::Starter plugin
 
 =head1 VERSION
 
-Version 1.55
+Version 1.56
 
 =cut
 
-our $VERSION = '1.55';
+our $VERSION = '1.56';
 
 =head1 SYNOPSIS
 
@@ -326,6 +326,22 @@ You should have received a copy of the GNU Lesser General Public
 License along with this program; if not, write to the Free
 Software Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA
 02111-1307 USA.
+EOT
+    },
+    {
+        license => 'apache',
+        blurb => <<'EOT',
+Licensed under the Apache License, Version 2.0 (the "License");
+you may not use this file except in compliance with the License.
+You may obtain a copy of the License at
+
+    L<http://www.apache.org/licenses/LICENSE-2.0>
+
+Unless required by applicable law or agreed to in writing, software
+distributed under the License is distributed on an "AS IS" BASIS,
+WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
+See the License for the specific language governing permissions and
+limitations under the License.
 EOT
     },
     ];
@@ -963,21 +979,8 @@ This methods creates a MANIFEST file using Module::Build's methods.
 =cut
 
 sub create_MB_MANIFEST {
-    my $self     = shift;
-    my $orig_dir = cwd();
-
-    # create the MANIFEST in the correct path
-    chdir $self->{'basedir'} || die "Can't reach basedir: $!\n";
-
-    my $name = $self->{'main_module'};
-    $name || die q{Couldn't find valid name for distribution};
-
-    require Module::Build;
-    my $mb = Module::Build->new( module_name => $name, verbose => 0 )
-                          ->dispatch('manifest');
-
-    # return to our original path, wherever it was
-    chdir $orig_dir || die "Can't return to original dir: $!\n";
+    my $self = shift;
+    $self->create_EUMM_MANIFEST;
 }
 
 =head2 create_MI_MANIFEST
@@ -1007,10 +1010,8 @@ sub create_EUMM_MANIFEST {
     chdir $self->{'basedir'} || die "Can't reach basedir: $!\n";
 
     require ExtUtils::Manifest;
-    ExtUtils::Manifest->import('mkmanifest');
     $ExtUtils::Manifest::Quiet = 0;
-
-    mkmanifest();
+    ExtUtils::Manifest::mkmanifest();
 
     # return to our original path, wherever it was
     chdir $orig_dir || die "Can't return to original dir: $!\n";
